@@ -1,6 +1,5 @@
-﻿#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to define CloudWatch alarms in x-alarms and match these to services
@@ -11,11 +10,12 @@ from troposphere import GetAtt, Output, Ref
 from troposphere.cloudwatch import Alarm as CWAlarm
 from troposphere.cloudwatch import CompositeAlarm, MetricDimension
 
-from ecs_composex.alarms.alarms_stack import Alarm, create_alarms
-from ecs_composex.common import LOG, add_outputs, add_parameters
+from ecs_composex.alarms.alarms_helpers import create_alarms
+from ecs_composex.alarms.alarms_stack import Alarm
+from ecs_composex.common import LOG, add_outputs, add_parameters, add_update_mapping
 from ecs_composex.common.cfn_params import Parameter
-from ecs_composex.ecs.ecs_params import CLUSTER_NAME, SERVICE_SCALING_TARGET, SERVICE_T
-from ecs_composex.ecs.ecs_scaling import (
+from ecs_composex.ecs.ecs_params import CLUSTER_NAME, SERVICE_SCALING_TARGET
+from ecs_composex.ecs.service_scaling.helpers import (
     generate_alarm_scaling_out_policy,
     reset_to_zero_policy,
 )
@@ -45,15 +45,6 @@ def get_alarm_actions(alarm):
     return okay_actions, alarm_actions
 
 
-def handle_services_alarm_access(alarm):
-    """
-    Function to grant describe access onto the alarm
-
-    :param alarm:
-    :return:
-    """
-
-
 def add_service_actions(
     alarm, alarms_stack, target, scaling_in_policy, scaling_out_policy
 ):
@@ -204,7 +195,7 @@ def handle_compose_topics(alarm, alarms_stack, settings, topic_def, notify_on):
     :return:
     """
     try:
-        topic = settings.compose_content[SNS_KEY][Topic.keyword][topic_def[SNS_KEY]]
+        topic = settings.compose_content[SNS_KEY][topic_def[SNS_KEY]]
     except KeyError:
         LOG.error(f"No topic {topic_def[SNS_KEY]} found in {SNS_KEY}.{Topic.keyword}")
         raise
@@ -217,13 +208,12 @@ def handle_compose_topics(alarm, alarms_stack, settings, topic_def, notify_on):
         alarms_stack.Parameters.update({topic_arn["Name"]: topic_arn["ImportValue"]})
         map_topic_to_action(alarm, notify_on, Ref(topic_arn["ImportParameter"]))
     else:
-        if keyisset(SNS_KEY, settings.mappings) and keyisset(
-            topic.logical_name, settings.mappings[SNS_KEY]
-        ):
-            alarms_stack.stack_template.add_mapping(
-                topic.module_name, settings.mappings[SNS_KEY]
-            )
-            map_topic_to_action(alarm, notify_on, topic_arn["ImportValue"])
+        add_update_mapping(
+            alarms_stack.stack_template,
+            topic.module.mapping_key,
+            settings.mappings[topic.module.mapping_key],
+        )
+        map_topic_to_action(alarm, notify_on, topic_arn["ImportValue"])
 
 
 def handle_alarm_topics(alarm, alarms_stack, settings):
@@ -246,11 +236,13 @@ def handle_alarm_topics(alarm, alarms_stack, settings):
             if not keyisset(SNS_KEY, settings.compose_content) or (
                 keyisset(SNS_KEY, settings.compose_content)
                 and not keyisset(
-                    topic[SNS_KEY], settings.compose_content[SNS_KEY][Topic.keyword]
+                    topic[SNS_KEY],
+                    settings.compose_content[SNS_KEY],
                 )
             ):
                 raise KeyError(
-                    f"There is no topic {topic[SNS_KEY]} defined in {SNS_KEY}"
+                    f"There is no topic {topic[SNS_KEY]} defined in {SNS_KEY}",
+                    settings.compose_content[SNS_KEY].keys(),
                 )
             handle_compose_topics(alarm, alarms_stack, settings, topic, notify_on)
 
@@ -305,7 +297,6 @@ def set_services_alarms(settings):
     Function to create and assign alarms to services
 
     :param ecs_composex.common.settings.ComposeXSettings settings:
-    :return:
     """
     for family in settings.families.values():
         if not family.predefined_alarms:
@@ -328,7 +319,7 @@ def set_services_alarms(settings):
                     alarm_name, alarm_definition, family.logical_name, settings
                 )
                 family_alarms.append(the_alarm)
-        create_alarms(family.template, settings, family_alarms)
+        create_alarms(family.template, family_alarms)
         for alarm in family_alarms:
             dimensions = [
                 MetricDimension(**{"Name": "ClusterName", "Value": Ref(CLUSTER_NAME)}),
