@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """"
 Common parameters for CFN
@@ -15,21 +14,18 @@ from troposphere import AWS_STACK_ID
 from troposphere import Parameter as CfnParameter
 from troposphere import Ref, Select, Split
 
-COMPUTE_STACK_NAME = "Ec2Compute"
-VPC_STACK_NAME = "vpc"
-MESH_TITLE = "RootMesh"
-PRIVATE_MAP_TITLE = "CloudMapVpcNamespace"
-PUBLIC_MAP_TITLE = "CloudMapPublicNamespace"
-PUBLIC_ZONE_TITLE = "Route53PublicZone"
-
 
 class Parameter(CfnParameter):
     """
     Class to extend the default Parameter behaviour
     """
 
-    def __init__(self, title, return_value=None, **kwargs):
+    def __init__(
+        self, title, return_value=None, group_label=None, label=None, **kwargs
+    ):
         self.return_value = return_value
+        self.group_label = group_label if group_label else "Uncategorized parameters"
+        self.label = label
         super().__init__(title, **kwargs)
 
 
@@ -41,17 +37,4 @@ ROOT_STACK_NAME = Parameter(
     Description="When part of a combined deployment, represents to the top stack name",
 )
 
-USE_FLEET_T = "UseSpotFleetHosts"
-USE_FLEET = Parameter(
-    USE_FLEET_T, Type="String", Default="False", AllowedValues=["True", "False"]
-)
-
-USE_ONDEMAND_T = "UseOnDemandHosts"
-USE_ONDEMAND = Parameter(
-    USE_ONDEMAND_T,
-    Type="String",
-    Default="False",
-    AllowedValues=["True", "False"],
-)
-
 STACK_ID_SHORT = Select(0, Split("-", Select(2, Split("/", Ref(AWS_STACK_ID)))))
