@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Parameters relating to ECS.
@@ -12,7 +11,7 @@ which it heavily relies onto.
 You can change the names *values* so you like so long as you keep it Alphanumerical [a-zA-Z0-9]
 """
 
-from troposphere import And, Condition, Equals, Not, Or, Ref
+from troposphere import And, Condition, Equals, If, Not, Or, Ref
 
 from ecs_composex.ecs import ecs_params
 
@@ -51,10 +50,33 @@ USE_FARGATE_CON = Or(
 NOT_FARGATE_CON_T = "NotUsingFargate"
 NOT_FARGATE_CON = Not(Condition(USE_FARGATE_CON_T))
 
+USE_EXTERNAL_LT_T = "UseExternalLaunchType"
+USE_EXTERNAL_LT = Equals(Ref(ecs_params.LAUNCH_TYPE), "EXTERNAL")
+
 
 USE_LAUNCH_TYPE_CON_T = "UseLaunchType"
-USE_LAUNCH_TYPE_CON = Or(Condition(USE_EC2_CON_T), Condition(USE_FARGATE_LT_CON_T))
+USE_LAUNCH_TYPE_CON = Or(
+    Condition(USE_EC2_CON_T),
+    Condition(USE_FARGATE_LT_CON_T),
+    Condition(USE_EXTERNAL_LT_T),
+)
 
+USE_LINUX_OS_T = "UseLinuxOS"
+USE_LINUX_OS = Equals(
+    Ref(ecs_params.RUNTIME_OS_FAMILY), ecs_params.RUNTIME_OS_FAMILY.Default
+)
+
+USE_WINDOWS_OS_T = "UseWindowsOS"
+USE_WINDOWS_OS = Not(Condition(USE_LINUX_OS_T))
+
+USE_WINDOWS_OR_FARGATE_T = "UseWindowsOSorFargate"
+USE_WINDOWS_OR_FARGATE = Or(Condition(USE_WINDOWS_OS_T), Condition(USE_FARGATE_CON_T))
+
+IPC_FROM_HOST_CON_T = "IpcSetForHost"
+IPC_FROM_HOST_CON = Equals(Ref(ecs_params.IPC_MODE), "host")
+
+USE_EC2_OR_EXTERNAL_LT_CON_T = "UseEC2orExternal"
+USE_EC2_OR_EXTERNAL_LT_CON = Or(Condition(USE_EXTERNAL_LT_T), Condition(USE_EC2_CON_T))
 
 SERVICE_COUNT_ZERO_AND_FARGATE_CON_T = "ServiceCountZeroAndFargate"
 SERVICE_COUNT_ZERO_AND_FARGATE_CON = And(
@@ -69,8 +91,6 @@ NOT_USE_HOSTNAME_CON = Equals(
 USE_HOSTNAME_CON_T = "UseMicroserviceHostnameCondition"
 USE_HOSTNAME_CON = Not(Condition(NOT_USE_HOSTNAME_CON_T))
 
-CREATE_CLUSTER_CON_T = "CreateClusterCondition"
-CREATE_CLUSTER_CON = Equals(Ref(ecs_params.CREATE_CLUSTER), "True")
 GENERATED_CLUSTER_NAME_CON_T = "GenerateEcsClusterName"
 GENERATED_CLUSTER_NAME_CON = Not(
     Equals(Ref(ecs_params.CLUSTER_NAME), ecs_params.CLUSTER_NAME.Default)
@@ -82,3 +102,18 @@ GENERATED_LOG_GROUP_NAME_CON_T = "GenerateLogGroupName"
 GENERATED_LOG_GROUP_NAME_CON = Equals(
     Ref(ecs_params.LOG_GROUP_NAME), ecs_params.LOG_GROUP_NAME.Default
 )
+
+DISABLE_CAPACITY_PROVIDERS_CON_T = "DisableCapacityProviders"
+DISABLE_CAPACITY_PROVIDERS_CON = Or(
+    Condition(USE_LAUNCH_TYPE_CON_T), Condition(USE_CLUSTER_MODE_CON_T)
+)
+
+
+def use_external_lt_con(if_true, if_false) -> If:
+    """
+    Function to return the If() to simplify !If USE_EXTERNAL_LT_T
+
+    :return: If(USE_EXTERNAL_LT_T, if_true, if_false)
+    :rtype: If
+    """
+    return If(USE_EXTERNAL_LT_T, if_true, if_false)
