@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Module to help with defining the network settings for the ECS Service based on the family services definitions.
@@ -11,7 +10,7 @@ from copy import deepcopy
 from ipaddress import IPv4Interface
 from json import dumps
 
-from compose_x_common.compose_x_common import keyisset
+from compose_x_common.compose_x_common import keyisset, set_else_none
 from troposphere import AWS_ACCOUNT_ID, AWS_NO_VALUE, Ref, Sub
 from troposphere.ec2 import SecurityGroupIngress
 
@@ -111,9 +110,9 @@ def set_port_from_str(port: str):
         raise ValueError("target port is not valid", numbers_only.pattern)
     if not numbers_only.match(published):
         raise ValueError("published port is not valid", numbers_only.pattern)
-    if not (1 <= int(target) < (2 ** 16)):
+    if not (1 <= int(target) < (2**16)):
         raise ValueError(f"target port {target} is not between 1 and 65535")
-    if not (1 <= int(published) < (2 ** 16)):
+    if not (1 <= int(published) < (2**16)):
         raise ValueError(f"published port {published} is not between 1 and 65535")
 
     return published, target, protocol
@@ -138,14 +137,9 @@ def set_service_ports(ports):
                     "protocol": parts[2],
                     "published": int(parts[0]),
                     "target": int(parts[1]),
-                    "mode": "awsvpc",
                 }
             )
         elif isinstance(port, dict):
-            valid_keys = ["published", "target", "protocol", "mode"]
-            if not set(port).issubset(valid_keys):
-                raise KeyError("Valid keys are", valid_keys, "got", port.keys())
-            port["mode"] = "awsvpc"
             service_ports.append(port)
         elif isinstance(port, int):
             service_ports.append(
@@ -153,7 +147,6 @@ def set_service_ports(ports):
                     "protocol": "tcp",
                     "published": port,
                     "target": port,
-                    "mode": "awsvpc",
                 }
             )
     return service_ports
@@ -168,7 +161,7 @@ def lookup_security_group(settings, lookup):
     :return:
     """
     sg_re = re.compile(
-        r"(?:^arn:aws(?:-[a-z]+)?:ec2:[a-z0-9-]+:\d{12}:security-group/)([\S]+)$"
+        r"^arn:aws(?:-[a-z]+)?:ec2:[a-z0-9-]+:\d{12}:security-group/([\S]+)$"
     )
     ec2_types = {
         "ec2:security-group": {"regexp": sg_re.pattern},
@@ -185,7 +178,7 @@ def lookup_security_group(settings, lookup):
     return sg_re.match(sg_arn).groups()[0]
 
 
-class Ingress(object):
+class Ingress:
     """
     Class to group the configuration for Service network settings
     """
@@ -216,9 +209,22 @@ class Ingress(object):
             if keyisset(self.ext_sources_key, self.definition)
             else []
         )
-        self.ext_sources = [
-            dict(y) for y in set(tuple(x.items()) for x in self.ext_sources)
-        ]
+        self.ext_sources = []
+        if keyisset(self.ext_sources_key, self.definition):
+            cidrs = []
+            for ext_source in self.definition[self.ext_sources_key]:
+                source_cidr = set_else_none(
+                    self.ipv4_key,
+                    ext_source,
+                    set_else_none(self.ipv6_key, ext_source, None),
+                )
+                if source_cidr and source_cidr not in cidrs:
+                    self.ext_sources.append(ext_source)
+                else:
+                    LOG.warning(
+                        f"Ingress source {source_cidr} already defined in a previous Ingress rule."
+                    )
+
         self.services = (
             self.definition[self.services_key]
             if keyisset(self.services_key, self.definition)
@@ -232,39 +238,31 @@ class Ingress(object):
     def __repr__(self):
         return dumps(self.definition, indent=2)
 
-    def validate_aws_sources(self):
-        allowed_keys = ["Type", "Id", "Lookup"]
-        allowed_types = ["SecurityGroup", "PrefixList"]
-        for source in self.aws_sources:
-            if not all(key in allowed_keys for key in source.keys()):
-                raise KeyError(
-                    "Missing ingress properties. Got",
-                    source.keys,
-                    "Expected",
-                    allowed_keys,
-                )
-            if not source["Type"] in allowed_types:
-                raise ValueError(
-                    "Invalid type specified. Got",
-                    source["Type"],
-                    "Allowed one of ",
-                    allowed_types,
-                )
-
-    def set_aws_sources(self, settings, destination_title, sg_ref):
+    def set_aws_sources_ingress(self, settings, destination_title, sg_ref) -> None:
         """
         Method to define AWS Sources ingresses
 
+        :param settings:
         :param destination_title:
         :param sg_ref:
-        :return:
         """
-        self.validate_aws_sources()
         for source in self.aws_sources:
             for port in self.ports:
+                if (
+                    keyisset("Ports", source)
+                    and port["published"] not in source["Ports"]
+                ):
+                    continue
+                target_port = set_else_none(
+                    "published", port, alt_value=set_else_none("target", port, None)
+                )
+                if target_port is None:
+                    raise ValueError(
+                        "Wrong port definition value for security group ingress", port
+                    )
                 common_args = {
-                    "FromPort": port["published"],
-                    "ToPort": port["published"],
+                    "FromPort": target_port,
+                    "ToPort": target_port,
                     "IpProtocol": port["protocol"],
                     "GroupId": sg_ref,
                 }
@@ -280,13 +278,13 @@ class Ingress(object):
                     common_args.update(
                         {
                             "Description": Sub(
-                                f"From {sg_id} to {destination_title} on port {port['published']}"
+                                f"From {sg_id} to {destination_title} on port {target_port}"
                             )
                         }
                     )
                     self.aws_ingress_rules.append(
                         SecurityGroupIngress(
-                            f"From{NONALPHANUM.sub('', sg_id)}ToServiceOn{port['published']}",
+                            f"From{NONALPHANUM.sub('', sg_id)}ToServiceOn{target_port}",
                             SourceSecurityGroupId=sg_id,
                             SourceSecurityGroupOwnerId=Ref(AWS_ACCOUNT_ID),
                             **common_args,
@@ -295,31 +293,51 @@ class Ingress(object):
                 elif source["Type"] == "PrefixList":
                     self.aws_ingress_rules.append(
                         SecurityGroupIngress(
-                            f"From{NONALPHANUM.sub('', source['Id'])}ToServiceOn{port['published']}",
+                            f"From{NONALPHANUM.sub('', source['Id'])}ToServiceOn{target_port}",
                             SourcePrefixListId=source["Id"],
                             **common_args,
                         )
                     )
 
     def create_ext_sources_ingress_rule(
-        self, destination_tile, allowed_source, security_group, **props
-    ):
+        self, destination_title, allowed_source, security_group, **props
+    ) -> None:
+        """
+        Creates the Security Ingress rule for a CIDR based rule
+
+        :param str destination_title:
+        :param dict allowed_source:
+        :param security_group:
+        :param dict props:
+        """
         for port in self.ports:
+            target_port = set_else_none(
+                "published", port, alt_value=set_else_none("target", port, None)
+            )
+            if target_port is None:
+                raise ValueError(
+                    "Wrong port definition value for security group ingress", port
+                )
+            if (
+                keyisset("Ports", allowed_source)
+                and target_port not in allowed_source["Ports"]
+            ):
+                continue
             if keyisset("Name", allowed_source):
                 name = NONALPHANUM.sub("", allowed_source["Name"])
-                title = f"From{name.title()}To{port['published']}{port['protocol']}"
+                title = f"From{name.title()}To{target_port}{port['protocol']}"
                 description = Sub(
                     f"From {name.title()} "
-                    f"To {port['published']}{port['protocol']} for {destination_tile}"
+                    f"To {target_port}{port['protocol']} for {destination_title}"
                 )
             else:
                 title = (
                     f"From{flatten_ip(allowed_source[self.ipv4_key])}"
-                    f"To{port['published']}{port['protocol']}"
+                    f"To{target_port}{port['protocol']}"
                 )
                 description = Sub(
-                    f"Public {port['published']}{port['protocol']}"
-                    f" for {destination_tile}"
+                    f"Public {target_port}{port['protocol']}"
+                    f" for {destination_title}"
                 )
             self.ext_ingress_rules.append(
                 SecurityGroupIngress(
@@ -329,8 +347,8 @@ class Ingress(object):
                     else allowed_source["Description"],
                     GroupId=security_group,
                     IpProtocol=port["protocol"],
-                    FromPort=port["published"],
-                    ToPort=port["published"],
+                    FromPort=target_port,
+                    ToPort=target_port,
                     **props,
                 )
             )
@@ -346,7 +364,7 @@ class Ingress(object):
         :type security_group: str or troposphere.ec2.SecurityGroup or troposphere.Ref or Troposphere.GetAtt
         """
         if not self.ext_sources:
-            LOG.info("No external rules defined. Skipping.")
+            LOG.debug("No external rules defined. Skipping.")
             return
 
         for allowed_source in self.ext_sources:
@@ -362,7 +380,7 @@ class Ingress(object):
                     destination_tile, allowed_source, security_group, **props
                 )
 
-    def associate_aws_igress_rules(self, template):
+    def associate_aws_ingress_rules(self, template):
         """
         Method to associate AWS ingress rules to a specific template
 
@@ -373,7 +391,7 @@ class Ingress(object):
             if ingress_rule.title not in template.resources:
                 template.add_resource(ingress_rule)
 
-    def associate_ext_igress_rules(self, template):
+    def associate_ext_ingress_rules(self, template):
         """
         Method to associate External ingress rules to a specific template
 
